@@ -25,6 +25,7 @@
 
 class ApollonListView : public KListView
 {
+	Q_OBJECT
 	public:
 		ApollonListView(QWidget* parent);
 
@@ -32,6 +33,12 @@ class ApollonListView : public KListView
 		QSize minimumSizeHint() const;
 		QSize minimumSize() const;
 		
+		void resizeEvent( QResizeEvent* e );
+		
+	public slots:
+		void slotAdjustGeometry();
+		void setProgressBarType(int type);
+		
 };
 
 #endif
