@@ -195,6 +195,8 @@ ApollonTransferTab::ApollonTransferTab(QWidget *parent, const char *name, giFTCo
 	connect(m_upList, SIGNAL(expanded(QListViewItem *)), this, SLOT(updateUploadSources(QListViewItem *)));
 	connect(m_upList, SIGNAL(selectionChanged()), this, SLOT(slotClickedUpListView()));
 	
+	setProgressBarType(0);
+	
 	//	splitter->setResizeMode(upBox, QSplitter::KeepSize);
 	QValueList<int> valuelist;
 	valuelist.append(200);
@@ -218,6 +220,13 @@ ApollonTransferTab::~ApollonTransferTab()
 	config->sync();
 }
 
+void ApollonTransferTab::setProgressBarType(int type)
+{
+	m_progressBarType = type;
+	m_downList->setProgressBarType(type);
+	m_upList->setProgressBarType(type);
+}
+
 void ApollonTransferTab::slotClickedDownListView() 
 {
 	m_downList->blockSignals(true); 
@@ -246,6 +255,7 @@ void ApollonTransferTab::addDownloadViewItem(QString line)
 	float   progress = 100 * ((float) transmit / (float) size);
 
 	ApollonTransferViewItem *item = new ApollonTransferViewItem(m_downList, "download", ID, protocol_name);
+	item->setProgressBarType(m_progressBarType);
 
 	item->setHash(hash);
 	item->setName(file);
@@ -261,6 +271,7 @@ void ApollonTransferTab::addDownloadViewItem(QString line)
 	{
 		QString source = line.section("SOURCE {", i + 1, i + 1);
 		ApollonTransferViewItem *sourceitem = new ApollonTransferViewItem(item);
+		sourceitem->setProgressBarType(m_progressBarType);
 
 		transmit = giFTConnection::searchKey("transmit", source).toInt();
 		progress = 100 * ((float) transmit / (float) size);
@@ -290,7 +301,7 @@ void ApollonTransferTab::delDownloadViewItem(QString line)
 	if(item->size() == item->transmit())
 	{
 		item->setStatus(i18n("Completed"));
-		item->setProgress(-1);
+		item->setProgress(100);
 
 		
 		KIconLoader *loader = KGlobal::iconLoader();
@@ -311,6 +322,7 @@ void ApollonTransferTab::delDownloadViewItem(QString line)
 	}
 	else
 	{
+		kdDebug() << k_funcinfo << " deleted a file" << endl;
 		item->setStatus(i18n("Canceled"));
 		item->setProgress(-1);
 	}
@@ -327,6 +339,7 @@ void ApollonTransferTab::addUploadViewItem(QString line)
 	float   progress = 100 * ((float) transmit / (float) size);
 
 	ApollonTransferViewItem *item = new ApollonTransferViewItem(m_upList, "upload", ID, protocol_name);
+	item->setProgressBarType(m_progressBarType);
 
 	item->setName(file);
 	item->setSize(size);
@@ -343,6 +356,7 @@ void ApollonTransferTab::addUploadViewItem(QString line)
 		progress = 100 * ((float) transmit / (float) size);
 
 		ApollonTransferViewItem *sourceitem = new ApollonTransferViewItem(item);
+		sourceitem->setProgressBarType(m_progressBarType);
 
 		sourceitem->setName(giFTConnection::searchKey("user", source));
 		sourceitem->setSize(transmit);
@@ -365,7 +379,7 @@ void ApollonTransferTab::delUploadViewItem(QString line)
 	if(item->size() == item->transmit())
 	{
 		item->setStatus(i18n("Completed"));
-		item->setProgress(-1);
+		item->setProgress(100);
 	}
 	else
 	{
@@ -426,6 +440,7 @@ void ApollonTransferTab::updateDownloadSources(QListViewItem *item)
 		if(sourceItem == 0)
 		{
 			sourceItem = new ApollonTransferViewItem(item);
+			sourceItem->setProgressBarType(m_progressBarType);
 		}
 
 		QString sourceName =   giFTConnection::searchKey("user", source);
@@ -497,6 +512,7 @@ void ApollonTransferTab::updateUploadSources(QListViewItem *item)
    		if(sourceItem == 0)
 		{
 			sourceItem = new ApollonTransferViewItem(item);
+			sourceItem->setProgressBarType(m_progressBarType);
 		}
 
 		QString sourceName =   giFTConnection::searchKey("user", source);
@@ -540,6 +556,7 @@ void ApollonTransferTab::addSourceItem(QString line)
 	}
 
 	ApollonTransferViewItem *sourceItem = new ApollonTransferViewItem(item);
+	sourceItem->setProgressBarType(m_progressBarType);
 
 	sourceItem->setName(giFTConnection::searchKey("user", line));
 	sourceItem->setStatus(giFTConnection::searchKey("status", line));
@@ -685,6 +702,11 @@ void ApollonTransferTab::cancelFiles(ApollonListView* list)
 	{
 		for (QValueList<ApollonTransferViewItem*>::Iterator it = itemList.begin(); it != itemList.end(); ++it) {
 			m_gcn->makeTransferRequest((*it)->id(), "cancel");
+			for (QMap<int, ApollonTransferViewItem*>::Iterator  ait = m_sourceSearchIDs.begin(); ait != m_sourceSearchIDs.end(); ait++) {
+				if ((*it) == m_sourceSearchIDs[ait.key()]) {
+					m_sourceSearchIDs.remove(ait);
+				}
+			}
 			emit sigDeleteHash( (*it)->hash() );
 			delete (*it);
 		}
@@ -700,53 +722,53 @@ void ApollonTransferTab::removeSourceitem()
 	int del_id;
 	ApollonTransferViewItem* item = (ApollonTransferViewItem *) m_downList->firstChild();
 	while(item != 0)
+	{
+		while(!item->firstChild())
 		{
-			while(!item->firstChild())
+			if ( !item->nextSibling())
 			{
-				 if ( !item->nextSibling())
-				{
-					finish=1; 
-					break;
-				 }
-				 else 
-				 {
-				 	item=item->nextSibling();
-				}
-			 }
-			if (finish==1)
+				finish=1; 
 				break;
-			item=item->firstChild();
-			while(item != 0)
-			{
-				if(item->isSelected())
-				{
-					strlist += item->text(0);
-				}
-				if(item->nextSibling()) 
-					item=item->nextSibling();
-				else break;
 			}
-			item=item->parent();
-			item=item->nextSibling();
+			else 
+			{
+				item=item->nextSibling();
+			}
 		}
+		if (finish==1)
+			break;
+		item=item->firstChild();
+		while(item != 0)
+		{
+			if(item->isSelected())
+			{
+				strlist += item->text(0);
+			}
+			if(item->nextSibling()) 
+				item=item->nextSibling();
+			else break;
+		}
+		item=item->parent();
+		item=item->nextSibling();
+	}
 	int answer = KMessageBox::questionYesNoList (this, i18n("Do you want to remove these sources?"),  strlist, i18n("Deletion"));
 	if (answer == KMessageBox::Yes)
 	{
-		 item = (ApollonTransferViewItem *) m_downList->firstChild();
-		 while(item != 0)
+		item = (ApollonTransferViewItem *) m_downList->firstChild();
+		while(item != 0)
 		{
 			while(!item->firstChild())
 			{
-				 if ( !item->nextSibling())
+				if ( !item->nextSibling())
 				{
 					finish=1; 
 					break;
-				 }
+				}
 				else 
 				{
 					item=item->nextSibling();
 				}
-			 }
+			}
 			if (finish==1)
 				break;
 			item=item->firstChild();
@@ -873,11 +895,12 @@ void ApollonTransferTab::sourceSearch(bool autoSearch)
 	{
 		sourcesearchitem = item;
 		if((autoSearch || sourcesearchitem->isSelected()) &&
-		   sourcesearchitem->status() != i18n("Canceled") && sourcesearchitem->status() != i18n("Completed"))
+				  sourcesearchitem->status() != i18n("Canceled") && sourcesearchitem->status() != i18n("Completed"))
 		{
 			int ID = m_gcn->getNewID();
-			m_sourceSearchIDs.append(ID);
+			m_sourceSearchIDs[ID] = sourcesearchitem;
 			m_gcn->makeLocateRequest(ID, sourcesearchitem->hash());
+			sourcesearchitem->startSourceSearch();
 		}
 		item = item->nextSibling();
 	}
@@ -911,10 +934,16 @@ void ApollonTransferTab::itemReply(QString line)
 
 			if(QString::compare(endsearch, line) == 0)
 			{
-				m_sourceSearchIDs.remove(receivedItemID);
+				ApollonTransferViewItem *item = m_sourceSearchIDs[receivedItemID];
+				if (item){
+					item->stopSourceSearch();
+					m_sourceSearchIDs.remove(receivedItemID);					
+				}
+				
 			}
 		}
 	}
+	
 }
 
 void ApollonTransferTab::browseUser()
